<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="224"/>
        <source>Drop Error</source>
        <translation>שגיאת השלכה</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="225"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>לא ניתן להטמיע את הקובץ/הכתובת ‚%1’ לתוך QuickLaunch כרגע</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="331"/>
        <source>Drop application
icons here</source>
        <translation>יש להשליך סמלי
יישומים לכאן</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>הזזה שמאלה</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>הזזה ימינה</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>הסרה מ־quicklaunch</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
